`Problem Set: propositional`

# The Stolen Diamond

A logic problem by Brandon Bennett

Your problem is to use propositional logic to represent the following example of reasoning, and use the Prover9 theorem prover to prove that the reasoning is valid.

Use the following template file to create your Prover9 encoding of the problem: `diamond.p9`

Marks: There are two marks for each sentence, making a total of 10 marks.

## Problem Statement

A1 | The diamond has been stolen!
A2 | If the diamond has been stolen, a thief got into the house.
A3 | If a thief got in, either the door was open or the window was smashed.
A4 | The window is not smashed.
Goal | The door was open.

### Non-Logical Vocabulary

Propositional Constants: `DiamondStolen`, `ThiefInHouse`, `DoorOpen`, `WindowSmashed`

#### Notes:

- A4 is in the present tense, whereas the other assumptions are in the past tense. We cannot easily represent tenses in propositional logic. Does this matter?